<?php

/**
 * Farazsms comments.
 *
 * @package Farazsms
 * @since 2.0.0
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class Farazsms_Comments.
 */
class Farazsms_Comments {
	/**
	 * Instance
	 *
	 * @access private
	 * @var object Class object.
	 * @since 2.0.0
	 */
	private static $instance;

	private static $disable_email_filed;
	private static $disable_website_filed;
	private static $disable_cookies;
	private static $add_mobile_field;
	private static $required_mobile_field;
	private static $notify_admin_for_comment;
	private static $comment_reply_pattern;
	private static $comment_pattern;
	private static $notify_admin_for_comment_pattern;
	private static $comment_phonebook_id;

	/**
	 * Initiator
	 *
	 * @return object Initialized object of class.
	 * @since 2.0.0
	 */
	public static function get_instance() {
		if ( ! isset( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Constructor
	 */
	public function __construct() {
		$comments_options = json_decode( get_option( 'farazsms_comments_options' ), true );
		if ( $comments_options ) {
			self::$disable_email_filed              = $comments_options['disable_email_filed'];
			self::$disable_website_filed            = $comments_options['disable_website_filed'];
			self::$disable_cookies                  = $comments_options['disable_cookies'];
			self::$add_mobile_field                 = $comments_options['add_mobile_field'];
			self::$required_mobile_field            = $comments_options['required_mobile_field'];
			self::$notify_admin_for_comment         = $comments_options['notify_admin_for_comment'];
			self::$comment_reply_pattern            = $comments_options['comment_reply_pattern'];
			self::$comment_pattern                  = $comments_options['comment_pattern'];
			self::$notify_admin_for_comment_pattern = $comments_options['notify_admin_for_comment_pattern'];
			self::$comment_phonebook_id             = $comments_options['comment_phonebook']['value'] ?? '';
		}

		add_filter( 'manage_edit-comments_columns', [ $this, 'comments_fsms_table_columns' ] );
		add_action( 'manage_comments_custom_column', [ $this, 'comments_fsms_table_columns_content' ], 10, 2 );
		add_action( 'comment_form_logged_in_after', [ $this, 'add_mobile_field_to_comment_form' ] );
		add_action( 'comment_form_after_fields', [ $this, 'add_mobile_field_to_comment_form' ] );
		add_action( 'preprocess_comment', [ $this, 'verify_comment_input' ] );
		add_action( 'comment_post', [ $this, 'save_mobile_field' ] );
		add_filter( 'comment_form_default_fields', [ $this, 'disable_comment_fields' ], 99, 1 );

		// Hook into WordPress comment hooks to trigger sending SMS notifications
		add_action( 'wp_insert_comment', [ $this, 'send_admin_sms_on_new_comment' ], 10, 2 );
		add_action( 'wp_set_comment_status', [ $this, 'send_author_sms_on_approved_comment' ], 10, 1 );
	}

	/**
	 * Comments table columns.
	 *
	 * @since 1.0.0
	 */
	public function comments_fsms_table_columns( $my_cols ) {
		$temp_columns = [
			'mobile' => __( 'Mobile', 'farazsms' ),
		];

		return array_slice( $my_cols, 0, 3, true ) + $temp_columns + array_slice( $my_cols, 3, null, true );
	}

	public function comments_fsms_table_columns_content( $column, $comment_ID ) {
		switch ( $column ) :

			case 'mobile' :
			{
				echo get_comment_meta( $comment_ID, 'mobile', true );
				break;
			}
		endswitch;
	}

	/**
	 * Add mobile field to comment form
	 */
	public function add_mobile_field_to_comment_form() {
		if ( ! self::$add_mobile_field === true ) {
			return;
		}

		$mobile_filed = '<p class="comment-form-phone uk-margin-top">';
		if ( self::$required_mobile_field === true ) {
			$mobile_filed .= ' <span class="required">*</span>';
			$required     = 'required="required"';
		}
		$mobile_filed .= '<input class="uk-input uk-width-large uk-display-block" type="text" name="mobile" id="mobile" placeholder=" ' . __( 'Like: 09300410381', 'farazsms' ) . '" /></p>';

		echo $mobile_filed;
	}

	// Save mobile field.
	public function save_mobile_field( $comment_id ) {
		if ( isset( $_POST['mobile'] ) ) {
			$mobile = Farazsms_Base::validate_mobile_number( esc_attr( $_POST['mobile'] ) );
			add_comment_meta( $comment_id, 'mobile', $mobile );
		}
		$this->send_admin_sms_on_new_comment( $comment_id );
	}

	// Verify comment input
	public function verify_comment_input( $comment_data ) {
		if ( empty( $comment_data['comment_parent'] ) && self::$required_mobile_field === true && empty( $_POST['mobile'] ) ) {
			wp_die( esc_html__( 'Error: Mobile number is required.', 'farazsms' ) );
		}

		return $comment_data;
	}


	/**
	 * Sends an SMS notification to the site admin when a new comment is submitted.
	 *
	 * @param int $comment_ID ID of the comment being submitted.
	 */
	public function send_admin_sms_on_new_comment( int $comment_ID ) {
		$comment               = get_comment( $comment_ID );
		$data                  = $this->comments_farazsms_shortcode( $comment, $comment_ID );
		$comment_author_mobile = get_comment_meta( $comment_ID, 'mobile', true ) ?? '';
		$user_name             = $comment->comment_author;
		$user                  = get_user_by( 'id', $comment->user_id );
		if ( isset( $user ) && is_object( $user ) ) {
			$is_admin = in_array( 'administrator', $user->roles );
		} else {
			$is_admin = false;
		}
		$admin_number = Farazsms_Base::$admin_number;

		if ( self::$comment_phonebook_id ) {
			$this->save_comment_mobile_to_phonebook( $comment_author_mobile, $user_name );
		}

		if ( self::$notify_admin_for_comment && ! $is_admin && ! empty( $admin_number ) ) {
			$this->send_comment_sms( $admin_number, self::$notify_admin_for_comment_pattern, $data );
		}

	}


	/**
	 * Sends an SMS notification to the author of a comment when their comment is approved, and they provided a mobile number.
	 *
	 * @param int $comment_ID
	 *
	 * @return void
	 */
	public function send_author_sms_on_approved_comment( int $comment_ID ): void {
		$comment = get_comment( $comment_ID );

		$comment_author_mobile        = get_comment_meta( $comment_ID, 'mobile', true ) ?? '';
		$comment_parent_author_mobile = '';
		$comment_parent               = $comment->comment_parent;

		if ( $comment_parent !== '0' ) {
			$comment_parent_author_mobile = get_comment_meta( $comment_parent, 'mobile', true ) ?? '';
		}

		if ( wp_get_comment_status( $comment_ID ) !== 'approved' ) {
			return;
		}

		$data = $this->comments_farazsms_shortcode( $comment, $comment_ID );

		if ( ! empty( $comment_author_mobile ) ) {
			$this->send_comment_sms( $comment_author_mobile, self::$comment_pattern, $data );
		}

		if ( ! empty( $comment_parent_author_mobile ) ) {
			$this->send_comment_sms( $comment_parent_author_mobile, self::$comment_reply_pattern, $data );
		}
	}

	/**
	 * Send comment sms.
	 *
	 * @param $phone
	 * @param $pattern
	 * @param $data
	 *
	 * @return bool|void
	 */
	public function send_comment_sms( $phone, $pattern, $data ) {
		$phone = Farazsms_Base::fsms_tr_num( $phone );
		if ( empty( $pattern ) ) {
			return;
		}

		$input_data     = [];
		$patternMessage = Farazsms_Ippanel::get_registered_pattern_variables( $pattern );
		if ( $patternMessage === null ) {
			return;
		}
		if ( str_contains( $patternMessage, '%title%' ) ) {
			$input_data['title'] = $data['title'];
		}
		if ( str_contains( $patternMessage, '%name%' ) ) {
			$input_data['name'] = $data['name'];
		}
		if ( str_contains( $patternMessage, '%email%' ) ) {
			$input_data['email'] = $data['email'];
		}
		if ( str_contains( $patternMessage, '%link%' ) ) {
			$input_data['link'] = $data['link'];
		}
		if ( str_contains( $patternMessage, '%content%' ) ) {
			$input_data['content'] = $data['content'];
		}

		return Farazsms_Ippanel::send_pattern( $pattern, $phone, $input_data );

	}

	/**
	 * Save comment mobile to phonebook.
	 */
	public function save_comment_mobile_to_phonebook( $number, $name ) {
		$list[0] = (object) [
			'number'       => $number,
			'name'         => $name,
			'phonebook_id' => (int) self::$comment_phonebook_id
		];
		Farazsms_Ippanel::save_list_of_phones_to_phonebook( $list );
	}

	/**
	 * Comments farazsms shortcode.
	 */
	public function comments_farazsms_shortcode( $comment, $comment_id ) {
		$post = get_post( $comment->comment_post_ID );

		return [
			'title'   => $post->post_title,
			'name'    => $comment->comment_author,
			'email'   => $comment->comment_author_email,
			'link'    => wp_get_shortlink( $post->ID ) . '#comment-' . $comment->comment_ID,
			'content' => $comment->comment_content,
			'parent'  => $comment->comment_parent
		];
	}

	/**
	 * Disable comment fields.
	 *
	 * @param $fields
	 *
	 * @return mixed
	 */
	public function disable_comment_fields( $fields ) {
		if ( self::$disable_email_filed ) {
			unset( $fields['email'] );
		}
		if ( self::$disable_website_filed ) {
			unset( $fields['url'] );
		}
		if ( self::$disable_cookies ) {
			unset( $fields['cookies'] );
		}

		return $fields;
	}
}

Farazsms_Comments::get_instance();
